@@ -10,11 +10,12 @@ except ImportError:
 import six
 from six.moves import html_parser
 
+__metaclass__ = type
 
 OpArg = collections.namedtuple('OpArg', 'opcode arg')
 
 
-class Bytecode_compat(object):
+class Bytecode_compat:
     def __init__(self, code):
         self.code = code
 
